#!/usr/bin/env bash
#
# For use ***outside*** of docker containers - needs to be easily accessible to DAs and such
#

set -o errexit -o nounset

function usage {
    echo "Usage: ingest-request [-c, -i] [workflow_request_id]

    This script sets off a Workspaces ingestion workflow of the specified type,
     given by the chosen option, for the provided workflow request id.

    Options:
    -c, --calibration   run the ingest_cal workflow for the specified request
    -i, --image         run the ingest_image workflow for the specified request
    -h, --help          display this help and exit
    "
}

option=$(echo "$1" | tr A-Z a-z)
case $option in
  --calibration|-c)
      action="ingest_cal"
  ;;
  --image|-i)
      action="ingest_image"
  ;;
  --help|-h)
      usage
  ;;
esac

WORKFLOW_SERVICE=$(capo -q edu.nrao.workspaces.WorkflowSettings.serviceUrl)

if [ "$action" = "ingest_cal" ]; then
    curl -X POST $WORKFLOW_SERVICE/workflows/std_calibration/requests/$2/ingest
fi
if [ "$action" = "ingest_image" ]; then
    curl -X POST $WORKFLOW_SERVICE/workflows/std_cms_image/requests/$2/ingest
fi
