""" Utilities for our workflow request REST service tests """

import datetime
from unittest import mock
from unittest.mock import MagicMock, patch

# pylint: disable=E0401, W0621

import pytest
from mock_alchemy.mocking import UnifiedAlchemyMagicMock

from workspaces.workflow.schema import Workflow, WorkflowRequest
from workspaces.workflow.services.workflow_info import WorkflowInfo
from workspaces.workflow.services.workflow_service import WorkflowService


def fix_timestamps(request: WorkflowRequest):
    """
    For patching save_request; sets created_at and updated_time

    :param request: a mocked WorkflowRequest
    :return:
    """
    request.created_at = datetime.datetime.now()
    request.updated_at = datetime.datetime.now()


@pytest.fixture
def mock_workflow_info() -> WorkflowInfo:
    """
    Pytest fixture providing a mock WorkflowInfo object; mocked object can be used
    like a normal WorkflowInfo instance

    :return: Mocked WorkflowInfo
    """

    null_workflow = Workflow(
        workflow_name="null",
    )

    null_workflow_query = (
        [mock.call.query(Workflow), mock.call.filter_by(name="null")],
        [null_workflow],
    )

    mock_session = UnifiedAlchemyMagicMock(data=[null_workflow_query])
    mock_workflow_info = WorkflowInfo(mock_session)
    mock_workflow_info.create_workflow_request = MagicMock()
    with patch(
        "workspaces.workflow.services.workflow_info.WorkflowInfo.save_request",
        side_effects=fix_timestamps,
    ):
        return mock_workflow_info


@pytest.fixture
def mock_workflow_service() -> WorkflowService:
    """
    Pytest fixture providing a mock WorkflowService object

    :return: Mocked WorkflowService
    """
    service = MagicMock()
    service.execute = MagicMock()
    return service
